@@ -153,6 +153,9 @@ static int DisplayPerf (struct diskperf_t *p_poPlugin)
     struct param_t *poConf = &(p_poPlugin->oConf.oParam);
     struct monitor_t *poMonitor = &(p_poPlugin->oMonitor);
     struct perfbar_t *poPerf = poMonitor->aoPerfBar;
+#if !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__sun__)
+    struct stat     oStat;
+#endif
     uint64_t        iInterval_ns, rbytes, wbytes, iRBusy_ns, iWBusy_ns;
     const double    K = 1.0 * 1000 * 1000 * 1000 / 1024 / 1024;
     /* bytes/ns --> MB/s */
@@ -169,10 +172,17 @@ static int DisplayPerf (struct diskperf_t *p_poPlugin)
 #if defined (__NetBSD__) || defined(__OpenBSD__) || defined(__sun__)
     status = DevGetPerfData (poConf->acDevice, &oPerf);
 #else
+    if (poConf->st_rdev == 0)
+    poConf->st_rdev = (stat (poConf->acDevice, &oStat) == -1 ? 0 : oStat.st_rdev);
     status = DevGetPerfData (&(poConf->st_rdev), &oPerf);
 #endif
-    if (status == -1)
+    if (status == -1) {
+    snprintf (acToolTips, sizeof(acToolTips), "%s: Device statistics unavailable.",
+              poConf->acTitle);
+    gtk_tooltips_set_tip (s_poToolTips, GTK_WIDGET (poMonitor->wEventBox),
+			  acToolTips, 0);
 	return (-1);
+    }
     if (poMonitor->oPrevPerf.timestamp_ns) {
 	iInterval_ns =
 	    oPerf.timestamp_ns - poMonitor->oPrevPerf.timestamp_ns;
@@ -643,13 +653,6 @@ static void SetDevice (Widget_t p_wTF, void *p_pvPlugin)
     int             status;
 
     status = stat (pcDevice, &oStat);
-    if (status == -1) {
-	xfce_dialog_show_error (NULL, NULL,
-                  "%s\n"
-		  "%s: %s (%d)",
-		  PLUGIN_NAME, pcDevice, strerror (errno), errno);
-	return;
-    }
     poConf->st_rdev = oStat.st_rdev;
 #endif
     memset (poConf->acDevice, 0, sizeof (poConf->acDevice));
